library (ggplot2)
library (nlme)
library (lme4)
library(readxl)
library(psych)
library(lmerTest)

#Specify the folder with the data files below
setwd("DATA FOLDER PATH")

#Read in data
data <- read_excel("Data.xlsx")

data$Condition = factor(data$Gender,levels=c("Female","Male"))

View(data)

################################################Descriptives
#Population etc
describe(data$Age)
describe(data$Duration_sec)



##################XOR Comparison sets.

#Read in data
dataAX <- read_excel("DataAnovaXOR.xlsx")

dataAX$cat = factor(dataAX$cat,levels=c("Rate_cause","Rate_posob","Rate_both", "Rate_neither"))

View(dataAX)


###########RANKING (Higher is better)

#Summaries
describe(data$XOR_Rate_cause) #m=-0.48
describe(data$XOR_Rate_posob) #m=6
describe(data$XOR_Rate_both) #m=1.26
describe(data$XOR_Rate_neither) #m=1.6


#Deviation from 0
t.test(data$XOR_Rate_cause, mu = 0, alternative = "two.sided") 
t.test(data$XOR_Rate_posob, mu = 0, alternative = "two.sided") #--> Sig above 0
t.test(data$XOR_Rate_both, mu = 0, alternative = "two.sided") #--> Sig above 0 (p= 0.045)
t.test(data$XOR_Rate_neither, mu = 0, alternative = "two.sided") #--> Sig above 0


#Anova XOR Rating ---------> Significant!
AnovaSupp = lm(score ~ cat, data = dataAX)
summary(AnovaSupp)

#Individual comparisons
# -------------> All comparisons show significant difference, except between both & neither
dataASVE <-subset(dataAX, (cat == "Rate_cause" | cat =="Rate_posob")) #-> pos ob better than cause 
AnovaMoti = lm(score ~ cat, data = dataASVE)
summary(AnovaMoti)
dataASVd <-subset(dataAX, (cat == "Rate_cause" | cat =="Rate_both")) #-> both better than cause --------> p-value: 0.04674
AnovaMoti = lm(score ~ cat, data = dataASVd)
summary(AnovaMoti)
dataASVF <-subset(dataAX, (cat == "Rate_cause" | cat =="Rate_neither"))# -> neither better than cause
AnovaMoti = lm(score ~ cat, data = dataASVF)
summary(AnovaMoti)

dataASED <-subset(dataAX, (cat == "Rate_posob" | cat =="Rate_both")) #-> pos ob better than both
AnovaMoti = lm(score ~ cat, data = dataASED)
summary(AnovaMoti)
dataASEF <-subset(dataAX, (cat == "Rate_posob" | cat =="Rate_neither")) # -> pos ob better than neither
AnovaMoti = lm(score ~ cat, data = dataASEF)
summary(AnovaMoti)

dataASDF <-subset(dataAX, (cat == "Rate_both" | cat =="Rate_neither"))  #->>>> Only one not significant
AnovaMoti = lm(score ~ cat, data = dataASDF)
summary(AnovaMoti)




##################OR Comparison sets.

#Read in data
dataAOr <- read_excel("DataAnovaOR.xlsx")

dataAOr$cat = factor(dataAOr$cat,levels=c("Rate_cause","Rate_posob","Rate_both", "Rate_neither"))

View(dataAOr)



#Summaries Rating
describe(data$OR_Rate_cause) #m= 5.9
describe(data$OR_Rate_posob) #m= 6.26
describe(data$OR_Rate_both) #m= 7.45
describe(data$OR_Rate_neither) #m= 0.46



#Deviation from 0
t.test(data$OR_Rate_cause, mu = 0, alternative = "two.sided")  #--> Sig above 0
t.test(data$OR_Rate_posob, mu = 0, alternative = "two.sided") #--> Sig above 0
t.test(data$OR_Rate_both, mu = 0, alternative = "two.sided") #--> Sig above 0 
t.test(data$OR_Rate_neither, mu = 0, alternative = "two.sided") #--> Not sig different from 0


#Anova OR ---------> Significant!
AnovaSupp = lm(score ~ cat, data = dataAOr)
summary(AnovaSupp)

#Individual comparisons
# -------------> All comparisons show significant difference, except between cause & obstacle only 
dataASVE <-subset(dataAOr, (cat == "Rate_cause" | cat =="Rate_posob")) #->>>> Only one ot significant
AnovaMoti = lm(score ~ cat, data = dataASVE)
summary(AnovaMoti)
dataASVd <-subset(dataAOr, (cat == "Rate_cause" | cat =="Rate_both")) #-> both better than cause
AnovaMoti = lm(score ~ cat, data = dataASVd)
summary(AnovaMoti)
dataASVF <-subset(dataAOr, (cat == "Rate_cause" | cat =="Rate_neither")) #-> cause better than neither
AnovaMoti = lm(score ~ cat, data = dataASVF)
summary(AnovaMoti)

dataASED <-subset(dataAOr, (cat == "Rate_posob" | cat =="Rate_both")) # -> both better than pos ob
AnovaMoti = lm(score ~ cat, data = dataASED)
summary(AnovaMoti)
dataASEF <-subset(dataAOr, (cat == "Rate_posob" | cat =="Rate_neither")) #-> pos ob better than neither
AnovaMoti = lm(score ~ cat, data = dataASEF)
summary(AnovaMoti)

dataASDF <-subset(dataAOr, (cat == "Rate_both" | cat =="Rate_neither"))  # ->both better than neither
AnovaMoti = lm(score ~ cat, data = dataASDF)
summary(AnovaMoti)


##################OPTION Comparison sets.

#Read in data
dataAOpt <- read_excel("DataAnovaOpt.xlsx")

dataAOpt$cat = factor(dataAOpt$cat,levels=c("Rate_cause","Rate_posob","Rate_both", "Rate_neither"))

View(dataAOpt)


#Summaries
describe(data$OP_Rate_cause) #m= 5.98
describe(data$OP_Rate_posob) #m= 6.7
describe(data$OP_Rate_both) #m= 7.86
describe(data$OP_Rate_neither) #m= 0.66

#Deviation from 0
t.test(data$OP_Rate_cause, mu = 0, alternative = "two.sided")  #--> Sig above 0
t.test(data$OP_Rate_posob, mu = 0, alternative = "two.sided") #--> Sig above 0
t.test(data$OP_Rate_both, mu = 0, alternative = "two.sided") #--> Sig above 0 
t.test(data$OP_Rate_neither, mu = 0, alternative = "two.sided") #--> Not sig different from 0


#Anova OR ---------> Significant!
AnovaSupp = lm(score ~ cat, data = dataAOpt)
summary(AnovaSupp)

#Individual comparisons
# -------------> All comparisons show significant difference, except between cause & obstacle only 
dataASVE <-subset(dataAOpt, (cat == "Rate_cause" | cat =="Rate_posob")) #->>>> Only one ot significant - p-value: 0.06405
AnovaMoti = lm(score ~ cat, data = dataASVE)
summary(AnovaMoti)
dataASVd <-subset(dataAOpt, (cat == "Rate_cause" | cat =="Rate_both")) # -> both better than cause
AnovaMoti = lm(score ~ cat, data = dataASVd)
summary(AnovaMoti)
dataASVF <-subset(dataAOpt, (cat == "Rate_cause" | cat =="Rate_neither")) # -> cause better than neither
AnovaMoti = lm(score ~ cat, data = dataASVF)
summary(AnovaMoti)

dataASED <-subset(dataAOpt, (cat == "Rate_posob" | cat =="Rate_both"))  #-> both better than pos ob
AnovaMoti = lm(score ~ cat, data = dataASED)
summary(AnovaMoti)
dataASEF <-subset(dataAOpt, (cat == "Rate_posob" | cat =="Rate_neither")) # -> pos ob better than neither
AnovaMoti = lm(score ~ cat, data = dataASEF)
summary(AnovaMoti)

dataASDF <-subset(dataAOpt, (cat == "Rate_both" | cat =="Rate_neither"))  # -> both better than neither
AnovaMoti = lm(score ~ cat, data = dataASDF)
summary(AnovaMoti)


